@@ -233,6 +233,8 @@ function setUpWorkspaceAcceptable() {
                 var url, center_x, center_y;
                 refreshMapActionsDivs();
                 // Load extent from workspace and zoom to it.
+	        // Disabled to avoid auto zoom
+	        /*
                 url = $(".workspace").attr(
                     "data-url-lizard-map-session-workspace-extent-temp");
                 $.getJSON(url, {}, function (extent) {
@@ -250,6 +252,7 @@ function setUpWorkspaceAcceptable() {
                                       map.getZoomForExtent(ol_extent) - 3);
                     }
                 });
+		*/
             });
         stretchOneSidebarBox();
         return false;
@@ -257,9 +260,17 @@ function setUpWorkspaceAcceptable() {
 }
 
 
-function setUpWorkspaceEmpty() {
-    var $workspace, workspace_id, url;
+/* Make the following workspace buttons work:
+- Trashcan next to "My Workspace" (workspace-empty-trigger)
+- Trashcan next to "Collage" (collage-empty-trigger)
+- (-) next to workspace-items (workspace-item-delete)
+- (-) next to snippet-items (snippet-delete)
+- Clickable snippets
+*/
+function setUpWorkspaceButtons() {
+    // Trashcan next to "My Workspace"
     $(".workspace-empty-trigger").live('click', function () {
+        var $workspace, workspace_id, url;
         $workspace = $(this).parents("div.workspace");
         workspace_id = $workspace.attr("data-workspace-id");
         url = $workspace.attr("data-url-lizard-map-workspace-item-empty");
@@ -272,6 +283,67 @@ function setUpWorkspaceEmpty() {
                 $workspace.updateWorkspace();
             });
     });
+    // Delete workspace item
+    $(".workspace-item-delete").live('click', function () {
+        var $workspace, workspace_id, url, object_id;
+        $workspace = $(this).parents("div.workspace");
+        workspace_id = $workspace.attr("data-workspace-id");
+        url = $workspace.attr(
+            "data-url-lizard-map-workspace-item-delete");
+        object_id = $(this).parents(".workspace-item").attr("data-object-id");
+        $.post(
+            url,
+            { object_id: object_id },
+            function () {
+                $workspace.updateWorkspace();
+            });
+        return false;
+    });
+    // Trashcan next to "Collage"
+    $(".collage-empty-trigger").live('click', function () {
+        var $workspace, collage_id, url;
+        $workspace = $(this).parents("div.workspace");
+        collage_id = $(this).attr("data-collage-id");
+        url = $workspace.attr("data-url-lizard-map-collage-empty");
+        addProgressAnimationIntoWorkspace();
+        $.post(
+            url, {collage_id: collage_id},
+	    function (data) {
+	        //remove progress
+                $workspace.find(".sidebarbox-action-progress").remove();
+                $workspace.updateWorkspace();
+            });
+    });
+    // Delete snippet
+    $(".snippet-delete").live('click', function () {
+        var $workspace, workspace_id, url, object_id;
+        $workspace = $(this).parents("div.workspace");
+        workspace_id = $workspace.attr("data-workspace-id");
+        url = $workspace.attr(
+            "data-url-lizard-map-snippet-delete");
+        object_id = $(this).parents(".snippet").attr("data-object-id");
+        $.post(
+            url,
+            { object_id: object_id },
+            function () {
+                $workspace.updateWorkspace();
+            });
+        return false;
+    });
+    // Make snippets clickable.
+    $("li.snippet").live('click', function (event) {
+        var $workspace, url, snippet_id;
+        $workspace = $(this).parents("div.workspace");
+        url = $workspace.attr("data-url-lizard-map-snippet-popup");
+        snippet_id = $(this).attr("data-object-id");
+        $.getJSON(
+            url,
+            { snippet_id: snippet_id },
+            function (data) {
+                show_popup(data);
+            }
+        );
+    });
 }
 
 
@@ -512,17 +584,30 @@ function setUpLegendEdit() {
 }
 
 
+/*
+Sends current extent and name of visible base layer.
+*/
 function mapSaveLocation() {
-    var url, extent;
+    var url, extent, visible_base_layer_name, i;
     url = $("#lizard-map-wms").attr("data-save-location-url");
     extent = map.getExtent();
+    visible_base_layer_name = "";
+
+    // Find the active base layer.
+    for (i = 0; i < map.layers.length; i = i + 1) {
+        if (map.layers[i].isBaseLayer && map.layers[i].visibility) {
+            visible_base_layer_name = map.layers[i].name;
+            break;
+        }
+    }
     $.ajax({
         type: 'POST',
         url: url,
         data: {bottom: extent.bottom,
                left: extent.left,
                right: extent.right,
-               top: extent.top},
+               top: extent.top,
+               base_layer_name: visible_base_layer_name},
         async: false,
         success: function () {}
     });
@@ -533,7 +618,7 @@ function mapSaveLocation() {
 $(document).ready(function () {
     setUpAddWorkspaceItem();
     setUpWorkspaceAcceptable();
-    setUpWorkspaceEmpty();
+    setUpWorkspaceButtons();
     setUpDatePopup();
     setUpDateUpdate();
     setUpNotFoundPopup();
