@@ -29,7 +29,8 @@ function updateLayers() {
 workspaces. Layers from other sources are assumed to be 'static' */
 function refreshLayers() {
     var $lizard_map_wms, base_layer,
-        base_layer_type, wms_url, wms_layers, osm_url, i;
+        base_layer_type, wms_url, wms_layers, osm_url, i,
+        selected_base_layer_name;
 
     // Remove all old layers.
     layers = [];
@@ -39,6 +40,7 @@ function refreshLayers() {
 
     // Set up all layers.
     $lizard_map_wms = $("#lizard-map-wms");
+    selected_base_layer_name = $lizard_map_wms.attr("data-selected-base-layer");
 
     $lizard_map_wms.find(".background-layer").each(function () {
         var google_type, data_google_type, layer_name, layer_type, url,
@@ -86,7 +88,11 @@ function refreshLayers() {
         // layers.base_layer
         map.addLayer(base_layer);
         // Set base layer if is_default.
-        if (is_default === "True") {
+        if ((selected_base_layer_name === "") &&
+            (is_default === "True")) {
+
+            map.setBaseLayer(base_layer);
+        } else if (selected_base_layer_name === layer_name) {
             map.setBaseLayer(base_layer);
         }
     });
@@ -123,9 +129,35 @@ function refreshLayers() {
 }
 
 
+function ZoomSlider(options) {
+    this.control = new OpenLayers.Control.PanZoomBar(options);
+
+    OpenLayers.Util.extend(this.control, {
+        draw: function (px) {
+            // initialize our internal div
+            OpenLayers.Control.prototype.draw.apply(this, arguments);
+            px = this.position.clone();
+
+            // place the controls
+            this.buttons = [];
+
+            var sz, centered;
+            sz = new OpenLayers.Size(18, 18);
+            centered = new OpenLayers.Pixel(px.x + sz.w / 2, px.y);
+
+            this._addButton("zoomin", "zoom-plus-mini.png", centered.add(0, 5), sz);
+            centered = this._addZoomBar(centered.add(0, sz.h + 5));
+            this._addButton("zoomout", "zoom-minus-mini.png", centered, sz);
+            return this.div;
+        }
+    });
+    return this.control;
+}
+
+
 function showMap() {
     var options, base_layer, MapClickControl, MapHoverControl,
-        map_click_control, map_hover_control,
+        map_click_control, zoom_panel, map_hover_control,
         javascript_click_handler_name, javascript_hover_handler_name,
         $lizard_map_wms, projection, display_projection, start_extent,
         start_extent_left, start_extent_top, start_extent_right,
@@ -171,7 +203,8 @@ function showMap() {
             displayProjection: new OpenLayers.Projection(display_projection),  // "EPSG:4326"
             units: "m",
             numZoomLevels: 18,
-            maxExtent: max_extent
+            maxExtent: max_extent,
+            controls: []
         };
     }
     else if (projection === "EPSG:28992")
@@ -181,12 +214,13 @@ function showMap() {
             displayProjection: new OpenLayers.Projection(display_projection),
             units: "m",
             resolutions: [364, 242, 161, 107, 71, 47, 31, 21, 14, 9, 6, 4, 2.7, 1.8, 0.9, 0.45, 0.2],
-            maxExtent: max_extent
+            maxExtent: max_extent,
+            controls: []
         };
     }
     else
     {
-        alert("Lizard-map onjuist geconfigureerd. Staat 'lizard_map.context_processors.processor.processor' in je context processors? Is de lizard_map fixture geladen?");
+        alert("Lizard-map onjuist geconfigureerd. Staat 'lizard_map.context_processors.processor.processor' in je context processors? Is de background_maps fixture geladen?");
     }
 
     // Map is globally defined.
@@ -275,6 +309,11 @@ function showMap() {
         map_hover_control.activate();
     }
 
+    zoom_panel = new OpenLayers.Control.Panel();
+    zoom_panel.addControls([ new ZoomSlider({ zoomStopHeight: 3 }) ]);
+    map.addControl(zoom_panel);
+    map.addControl(new OpenLayers.Control.Navigation());
+
     // Zoom to startpoint. Important to parse numbers, else a bug in
     // OpenLayers will initially prevent "+" from working.
     map.setCenter(start_extent.getCenterLonLat(),
