@@ -18,8 +18,6 @@ from lizard_map.daterange import SESSION_DT_START
 from lizard_map.daterange import SESSION_DT_END
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.daterange import current_period
-from lizard_map.daterange import default_start
-from lizard_map.daterange import default_end
 from lizard_map.daterange import deltatime_range
 from lizard_map.daterange import set_date_range
 from lizard_map.dateperiods import ALL
@@ -152,7 +150,8 @@ class ViewsTest(TestCase):
         client = Client()
         url = reverse('lizard_map.map_location_save')
         response = client.post(url, {'left': 100, 'top': 100,
-                                     'right': 150, 'bottom': 150})
+                                     'right': 150, 'bottom': 150,
+                                     'base_layer_name': 'Google standard'})
         self.assertEqual(response.status_code, 200)
 
     def test_map_location_load_default(self):
@@ -165,8 +164,7 @@ class ViewsTest(TestCase):
         self.assertEqual(
             result['extent'],
             {'top': '6964942', 'right': '1254790',
-             'left': '-14675', 'bottom': '6668977'}
-            )
+             'left': '-14675', 'bottom': '6668977'})
 
 
 class WorkspaceTest(TestCase):
@@ -380,6 +378,7 @@ class TestDateRange(TestCase):
     """Test daterange.py"""
 
     def setUp(self):
+
         class Mock(dict):
             pass
 
@@ -535,6 +534,7 @@ class TestAnimationSettings(TestCase):
         self.assertEquals(end.year, 2003)
 
     def setUp(self):
+
         class Mock(dict):
             pass
 
@@ -623,6 +623,7 @@ class UtilityTest(TestCase):
     """
     Tests utility.py, adapter.py, mapnik_helper.py
     """
+
     class MockSettings(object):
         pass
 
