@@ -17,7 +17,6 @@ from lizard_map.adapter import parse_identifier_json
 from lizard_map.animation import slider_layout_extra
 from lizard_map.coordinates import MapSettings
 from lizard_map.daterange import current_start_end_dates
-from lizard_map.daterange import DateRangeForm
 from lizard_map.models import Workspace
 from lizard_map.models import WorkspaceItem
 from lizard_map.models import WorkspaceCollage
@@ -31,6 +30,7 @@ from lizard_map.workspace import WorkspaceManager
 
 CUSTOM_LEGENDS = 'custom_legends'
 MAP_LOCATION = 'map_location'
+MAP_BASE_LAYER = 'map_base_layer'  # The selected base layer
 CRUMBS_HOMEPAGE = {'name': 'home', 'title': 'hoofdpagina', 'url': '/'}
 
 logger = logging.getLogger(__name__)
@@ -582,7 +582,10 @@ def snippet_popup(request, snippet_id=None):
 def collage_popup(request,
                   collage_id=None,
                   template='lizard_map/collage.html'):
-    """Render page with one collage in popup format"""
+    """Render page with one collage in popup format
+
+    collage_id in GET parameter.
+    """
     if collage_id is None:
         collage_id = request.GET.get('collage_id')
     collage = get_object_or_404(WorkspaceCollage, pk=collage_id)
@@ -595,6 +598,21 @@ def collage_popup(request,
         request=request)
 
 
+@never_cache
+def collage_empty(request):
+    """Clear collage for given collage_id.
+
+    collage_id is in POST parameter
+
+    TODO: check if workspace is actually yours
+    """
+    collage_id = request.POST.get('collage_id')
+    collage = get_object_or_404(WorkspaceCollage, pk=collage_id)
+    collage.delete()
+
+    return HttpResponse("")
+
+
 @never_cache
 def workspace_item_image(request, workspace_item_id):
     """Shows image corresponding to workspace item and location identifier(s)
@@ -937,17 +955,24 @@ contains a dictionary with fields x, y and zoom.
 
 def map_location_save(request):
     """
-    Save extent as strings (POST top, left, right, bottom) to session.
+    Save map layout in session.
+
+    - extent as strings (POST top, left, right, bottom).
+    - selected base layer name.
+
+
     """
     top = request.POST['top']
     left = request.POST['left']
     right = request.POST['right']
     bottom = request.POST['bottom']
+    base_layer_name = request.POST['base_layer_name']
     request.session[MAP_LOCATION] = {
         'top': top,
         'left': left,
         'right': right,
         'bottom': bottom}
+    request.session[MAP_BASE_LAYER] = base_layer_name
     return HttpResponse("")
 
 
@@ -959,4 +984,6 @@ def map_location_load_default(request):
     extent = map_settings.map_settings['start_extent']
     map_location = {'extent': extent}
 
+    request.session[MAP_BASE_LAYER] = ''  # Reset selected base layer.
+
     return HttpResponse(json.dumps(map_location))
